<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'auth_imap', language 'id', version '5.0'.
 *
 * @package     auth_imap
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['auth_imapchangepasswordurl_key'] = 'URL ubah sandi';
$string['auth_imapdescription'] = 'Metode ini menggunakan server IMAP untuk memeriksa apakah nama pengguna dan password sah.';
$string['auth_imaphost'] = 'Alamat server IMAP. Gunakan nomor IP, bukan nama DNS.';
$string['auth_imaphost_key'] = 'Tuan rumah';
$string['auth_imapnotinstalled'] = 'Tidak dapat menggunakan otentikasi IMAP. Modul PHP IMAP tidak diinstal.';
$string['auth_imapport'] = 'Nomor port server IMAP. Biasanya dipakai 143 atau 993.';
$string['auth_imaptype'] = 'Jenis server IMAP. Server IMAP dapat mempunyai berbagai jenis otentikasi dan negosiasi.';
$string['auth_imaptype_key'] = 'Tipe';
$string['pluginname'] = 'Gunakan server IMAP';
$string['privacy:metadata'] = 'Plugin otentikasi server IMAP tidak menyimpan data pribadi apa pun.';
